decode_trace

Function decode_trace 

pub fn decode_trace(buf: &[u8]) -> TreeLoop
Decode a Trace from a compact byte buffer.

Note: descriptor references are not preserved — ops with descriptors in the original trace will have descr: None after decoding, but the has-descriptor flag is still decoded (and could be used to reconstruct descriptors from a separate table).